//@line 4 "/builds/slave/tb-rel-c-esr38-lx_rpk_3-000000/l10n/eu/calendar/lightning-l10n.js"

//@line 6 "/builds/slave/tb-rel-c-esr38-lx_rpk_3-000000/l10n/eu/calendar/lightning-l10n.js"

//@line 9 "/builds/slave/tb-rel-c-esr38-lx_rpk_3-000000/l10n/eu/calendar/lightning-l10n.js"
pref("calendar.week.start", 1);

//@line 12 "/builds/slave/tb-rel-c-esr38-lx_rpk_3-000000/l10n/eu/calendar/lightning-l10n.js"
pref("calendar.week.d0sundaysoff", true);
pref("calendar.week.d1mondaysoff", false);
pref("calendar.week.d2tuesdaysoff", false);
pref("calendar.week.d3wednesdaysoff", false);
pref("calendar.week.d4thursdaysoff", false);
pref("calendar.week.d5fridaysoff", false);
pref("calendar.week.d6saturdaysoff", true);

pref("general.useragent.locale", "eu");

//@line 23 "/builds/slave/tb-rel-c-esr38-lx_rpk_3-000000/l10n/eu/calendar/lightning-l10n.js"
pref("calendar.categories.names", "Lanekoak,Deiak,Bezeroak,Hornitzaileak,Lehiaketak,Ideiak,Proiektuak,Begiratzekoak,Oporrak,Jai egunak,Bidaiak,Pertsonala,Familia,Kuadrila,Lagunak,Urtemugak,Urtebetetzeak,Opariak,Gogokoak,Hainbat");
